HeaderPrefix

Struct HeaderPrefix 

#[repr(C)]
pub struct HeaderPrefix { pub magic: [u8; 4], pub version: u32, pub remaining_header_bytes: u32, }
FILE FORMAT PREFIX LAYOUT. THIS MUST NEVER CHANGE The prefix is part of the on-disk binary format and is used for streaming / incremental parsing. If you modify the fields, their types, ordering, or size, all previously written files will become unreadable.

If format updates are needed, bump version instead and evolve the rest of the header format conditionally.

Fields

magic: [u8; 4]version: u32remaining_header_bytes: u32

Implementations

Source

impl HeaderPrefix

pub fn new() -> Self

pub fn length() -> usize

pub fn write_all(&self, cursor: &mut Cursor<&mut [u8]>) -> Result<(), Error>

pub fn parse(buffer: &[u8]) -> Result<(Option<HeaderPrefix>, usize), Error>