pub struct StreamDecryptor { /* private fields */ }Implementations
Sourceimpl StreamDecryptor
impl StreamDecryptor
Sourcepub fn with_password(
password: &str,
manifest_blob: &mut Blob,
) -> Result<Self, Error>
pub fn with_password( password: &str, manifest_blob: &mut Blob, ) -> Result<Self, Error>
Constructs an instance with a password and an encrypted manifest
Sourcepub fn decrypt_chunk(
&self,
cypherchunk: &mut CypherChunk,
) -> Result<DecryptedBlob, Error>
pub fn decrypt_chunk( &self, cypherchunk: &mut CypherChunk, ) -> Result<DecryptedBlob, Error>
Decrypts a chunk and returns decrypted text Takes ownership of the chunk and does the decryption in place
Sourcepub fn get_manifest(&self) -> &Manifest
pub fn get_manifest(&self) -> &Manifest
Gets the manifest associated with the file being decrypted